@@ -14,8 +14,22 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-const fabric = require('@umijs/fabric');
-
 module.exports = {
-  ...fabric.stylelint,
+  extends: [
+    'stylelint-config-standard',
+    'stylelint-config-css-modules',
+    'stylelint-config-rational-order',
+    'stylelint-config-prettier',
+  ],
+  plugins: ['stylelint-order', 'stylelint-declaration-block-no-ignored-properties'],
+  customSyntax: 'postcss-less',
+  rules: {
+    'no-descending-specificity': null,
+    'function-url-quotes': 'always',
+    'font-family-no-missing-generic-family-keyword': null,
+    'plugin/declaration-block-no-ignored-properties': true,
+    'unit-no-unknown': [true, { ignoreUnits: ['rpx'] }],
+    'selector-class-pattern': null,
+  },
+  ignoreFiles: ['**/*.js', '**/*.jsx', '**/*.tsx', '**/*.ts'],
 };
