@@ -18,14 +18,12 @@ export default {
   'page.consumer.form.itemRuleMessage.username':
     'Maximum length is 100, only letters, numbers and _ are supported.',
   'page.consumer.form.itemExtraMessage.username': 'Name should be unique',
-  'page.consumer.notification.warning.enableAuthenticationPlugin':
-    'Please enable at least one of the following authentication plugin:',
   'page.consumer.username': 'Name',
   'page.consumer.username.required': "Please enter the Consumer's name",
   'page.consumer.updateTime': 'Update Time',
   'page.consumer.list': 'Consumer List',
   'page.consumer.description':
-    'Consumers are the consumers of Routes, e.g developers, end users, API calls, etc. When creating a consumer, you need to bind at least one Authentication plugin.',
+    'Consumers are the consumers of Routes, e.g developers, end users, API calls, etc.',
   'page.consumer.create': 'Create Consumer',
   'page.consumer.configure': 'Configure Consumer',
 };
