@@ -17,5 +17,6 @@
 export default {
   'page.dashboard.empty.description.grafanaNotConfig': 'Grafanayı yapılandımardınız.',
   'page.dashboard.button.grafanaConfig': 'Yapılandır',
-  'page.dashboard.tip': 'Tarayıcı localStorage\'ında yönetim sayfası URL\'sini saklar, yalnızca yerel.',
+  'page.dashboard.tip':
+    "Tarayıcı localStorage'ında yönetim sayfası URL'sini saklar, yalnızca yerel.",
 };
