@@ -19,4 +19,6 @@ export default {
   'page.plugin.list': 'Plugin List',
   'page.plugin.list.enabled': 'List of enabled plugins',
   'page.plugin.market.config': 'Global Plugin List',
+  'page.plugin.edit': 'Configure Plugin Successfully',
+  'page.plugin.delete': 'Delete Plugin Successfully',
 };
