@@ -14,12 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package label
+package label_test
 
 import (
 	"testing"
+	"time"
 
-	. "github.com/onsi/ginkgo"
+	"github.com/apisix/manager-api/test/e2e/base"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 )
 
@@ -27,3 +29,8 @@ func TestLabel(t *testing.T) {
 	RegisterFailHandler(Fail)
 	RunSpecs(t, "Label Suite")
 }
+
+var _ = BeforeSuite(func() {
+	base.CleanAllResource()
+	time.Sleep(base.SleepTime)
+})
