@@ -18,12 +18,19 @@ package oidc_test
 
 import (
 	"testing"
+	"time"
 
-	. "github.com/onsi/ginkgo"
+	"github.com/apisix/manager-api/test/e2e/base"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 )
 
 func TestOidc(t *testing.T) {
 	RegisterFailHandler(Fail)
-	RunSpecs(t, "Oidc Suite")
+	RunSpecs(t, "OIDC Suite")
 }
+
+var _ = BeforeSuite(func() {
+	base.CleanAllResource()
+	time.Sleep(base.SleepTime)
+})
