@@ -14,23 +14,22 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package plugin_config
+package plugin_config_test
 
 import (
 	"testing"
 	"time"
 
-	"github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 
 	"github.com/apisix/manager-api/test/e2e/base"
 )
 
 func TestPluginConfig(t *testing.T) {
-	ginkgo.RunSpecs(t, "plugin config suite")
+	RunSpecs(t, "Plugin Config Suite")
 }
 
-var _ = ginkgo.AfterSuite(func() {
-	base.CleanResource("plugin_configs")
-	base.CleanResource("routes")
+var _ = BeforeSuite(func() {
+	base.CleanAllResource()
 	time.Sleep(base.SleepTime)
 })
