@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package route_online_debug
+package route_online_debug_test
 
 import (
 	"encoding/json"
@@ -23,9 +23,8 @@ import (
 	"path/filepath"
 	"time"
 
-	"github.com/onsi/ginkgo"
-	"github.com/onsi/ginkgo/extensions/table"
-	"github.com/onsi/gomega"
+	. "github.com/onsi/ginkgo/v2"
+	. "github.com/onsi/gomega"
 	"github.com/tidwall/gjson"
 
 	"github.com/apisix/manager-api/test/e2e/base"
@@ -42,19 +41,19 @@ var upstream map[string]interface{} = map[string]interface{}{
 	},
 }
 
-var _ = ginkgo.Describe("Route_Online_Debug_Route_Not_Exist", func() {
-	table.DescribeTable("Route_Online_Debug_Route_Not_Exist",
+var _ = Describe("Route_Online_Debug_Route_Not_Exist", func() {
+	DescribeTable("Route_Online_Debug_Route_Not_Exist",
 		func(tc base.HttpTestCase) {
 			base.RunTestCase(tc)
 		},
-		table.Entry("hit route that not exist", base.HttpTestCase{
+		Entry("hit route that not exist", base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
 			Path:         "/hello_",
 			ExpectStatus: http.StatusNotFound,
 			ExpectBody:   "{\"error_msg\":\"404 Route Not Found\"}\n",
 		}),
-		table.Entry("online debug route with query params", base.HttpTestCase{
+		Entry("online debug route with query params", base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPost,
 			Path:   "/apisix/admin/debug-request-forwarding",
@@ -73,8 +72,8 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_Not_Exist", func() {
 	)
 })
 
-var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Query_Params", func() {
-	ginkgo.It("hit route that not exist", func() {
+var _ = Describe("Route_Online_Debug_Route_With_Query_Params", func() {
+	It("hit route that not exist", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -83,7 +82,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Query_Params", func() {
 			ExpectBody:   "{\"error_msg\":\"404 Route Not Found\"}\n",
 		})
 	})
-	ginkgo.It("create route with query params", func() {
+	It("create route with query params", func() {
 		var routeBody map[string]interface{} = map[string]interface{}{
 			"name":    "route1",
 			"uri":     "/hello",
@@ -94,7 +93,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Query_Params", func() {
 			"upstream": upstream,
 		}
 		_routeBody, err := json.Marshal(routeBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodPut,
@@ -104,7 +103,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Query_Params", func() {
 			ExpectStatus: http.StatusOK,
 		})
 	})
-	ginkgo.It("online debug route with query params", func() {
+	It("online debug route with query params", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPost,
@@ -122,7 +121,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Query_Params", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("delete the route just created", func() {
+	It("delete the route just created", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -131,7 +130,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Query_Params", func() {
 			ExpectStatus: http.StatusOK,
 		})
 	})
-	ginkgo.It("hit the route just deleted", func() {
+	It("hit the route just deleted", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -143,8 +142,8 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Query_Params", func() {
 	})
 })
 
-var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Header_Params", func() {
-	ginkgo.It("hit route that not exist", func() {
+var _ = Describe("Route_Online_Debug_Route_With_Header_Params", func() {
+	It("hit route that not exist", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -153,7 +152,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Header_Params", func() {
 			ExpectBody:   "{\"error_msg\":\"404 Route Not Found\"}\n",
 		})
 	})
-	ginkgo.It("create route with header params", func() {
+	It("create route with header params", func() {
 		var routeBody map[string]interface{} = map[string]interface{}{
 			"name":    "route1",
 			"uri":     "/hello",
@@ -164,7 +163,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Header_Params", func() {
 			"upstream": upstream,
 		}
 		_reqRouteBody, err := json.Marshal(routeBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodPut,
@@ -175,7 +174,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Header_Params", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("online debug route with header params", func() {
+	It("online debug route with header params", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPost,
@@ -193,7 +192,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Header_Params", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("online debug route with header params(add Content-type to header params to create route)", func() {
+	It("online debug route with header params(add Content-type to header params to create route)", func() {
 		var routeBody map[string]interface{} = map[string]interface{}{
 			"name":     "route2",
 			"status":   1,
@@ -202,7 +201,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Header_Params", func() {
 			"upstream": upstream,
 		}
 		_reqRouteBody, err := json.Marshal(routeBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPost,
@@ -221,7 +220,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Header_Params", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("hit the route (r2)", func() {
+	It("hit the route (r2)", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -231,7 +230,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Header_Params", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("delete the route just created (r1)", func() {
+	It("delete the route just created (r1)", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -240,7 +239,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Header_Params", func() {
 			ExpectStatus: http.StatusOK,
 		})
 	})
-	ginkgo.It("delete the route just created (r2)", func() {
+	It("delete the route just created (r2)", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -249,7 +248,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Header_Params", func() {
 			ExpectStatus: http.StatusOK,
 		})
 	})
-	ginkgo.It("hit the route just deleted (r1)", func() {
+	It("hit the route just deleted (r1)", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -259,7 +258,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Header_Params", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("hit the route just deleted  (r2)", func() {
+	It("hit the route just deleted  (r2)", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -271,8 +270,8 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Header_Params", func() {
 	})
 })
 
-var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Body_Params", func() {
-	ginkgo.It("hit route that not exist", func() {
+var _ = Describe("Route_Online_Debug_Route_With_Body_Params", func() {
+	It("hit route that not exist", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -281,7 +280,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Body_Params", func() {
 			ExpectBody:   "{\"error_msg\":\"404 Route Not Found\"}\n",
 		})
 	})
-	ginkgo.It("create route with method POST", func() {
+	It("create route with method POST", func() {
 		var routeBody map[string]interface{} = map[string]interface{}{
 			"name":     "route1",
 			"uri":      "/hello",
@@ -289,7 +288,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Body_Params", func() {
 			"upstream": upstream,
 		}
 		_reqRouteBody, err := json.Marshal(routeBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodPut,
@@ -300,7 +299,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Body_Params", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("online debug route with body params", func() {
+	It("online debug route with body params", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPost,
@@ -322,7 +321,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Body_Params", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("delete the route just created", func() {
+	It("delete the route just created", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -331,7 +330,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Body_Params", func() {
 			ExpectStatus: http.StatusOK,
 		})
 	})
-	ginkgo.It("hit the route just deleted", func() {
+	It("hit the route just deleted", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -342,8 +341,8 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Body_Params", func() {
 		})
 	})
 })
-var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Basic_Auth", func() {
-	ginkgo.It("hit route that not exist", func() {
+var _ = Describe("Route_Online_Debug_Route_With_Basic_Auth", func() {
+	It("hit route that not exist", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -352,7 +351,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Basic_Auth", func() {
 			ExpectBody:   "{\"error_msg\":\"404 Route Not Found\"}\n",
 		})
 	})
-	ginkgo.It("create route enable basic-auth plugin", func() {
+	It("create route enable basic-auth plugin", func() {
 		var routeBody map[string]interface{} = map[string]interface{}{
 			"name": "route1",
 			"uri":  "/hello",
@@ -363,7 +362,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Basic_Auth", func() {
 			"upstream": upstream,
 		}
 		_reqRouteBody, err := json.Marshal(routeBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodPut,
@@ -374,7 +373,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Basic_Auth", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("make sure the consumer is not created", func() {
+	It("make sure the consumer is not created", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodGet,
@@ -383,7 +382,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Basic_Auth", func() {
 			ExpectStatus: http.StatusNotFound,
 		})
 	})
-	ginkgo.It("create consumer", func() {
+	It("create consumer", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPut,
@@ -404,7 +403,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Basic_Auth", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("online debug with basic-auth", func() {
+	It("online debug with basic-auth", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPost,
@@ -421,7 +420,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Basic_Auth", func() {
 			ExpectBody:   `{"code":0,"message":"","data":{"code":200,"header":{"Connection":["keep-alive"],"Content-Type":["application/octet-stream"]`,
 		})
 	})
-	ginkgo.It("online debug without basic-auth", func() {
+	It("online debug without basic-auth", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPost,
@@ -438,7 +437,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Basic_Auth", func() {
 			ExpectBody:   `{"code":0,"message":"","data":{"code":401,"header":{"Connection":["keep-alive"],"Content-Type":["text/plain; charset=utf-8"],`,
 		})
 	})
-	ginkgo.It("delete the route just created", func() {
+	It("delete the route just created", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -447,7 +446,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Basic_Auth", func() {
 			ExpectStatus: http.StatusOK,
 		})
 	})
-	ginkgo.It("hit the route just deleted", func() {
+	It("hit the route just deleted", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -457,7 +456,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Basic_Auth", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("delete consumer", func() {
+	It("delete consumer", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -468,9 +467,8 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Basic_Auth", func() {
 	})
 })
 
-var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Key_Auth", func() {
-
-	ginkgo.It("hit route that not exist", func() {
+var _ = Describe("Route_Online_Debug_Route_With_Key_Auth", func() {
+	It("hit route that not exist", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -479,7 +477,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Key_Auth", func() {
 			ExpectBody:   "{\"error_msg\":\"404 Route Not Found\"}\n",
 		})
 	})
-	ginkgo.It("create route enable key-auth plugin", func() {
+	It("create route enable key-auth plugin", func() {
 		var routeBody map[string]interface{} = map[string]interface{}{
 			"name": "route1",
 			"uri":  "/hello",
@@ -490,7 +488,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Key_Auth", func() {
 			"upstream": upstream,
 		}
 		_reqRouteBody, err := json.Marshal(routeBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodPut,
@@ -501,7 +499,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Key_Auth", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("make sure the consumer is not created", func() {
+	It("make sure the consumer is not created", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodGet,
@@ -510,7 +508,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Key_Auth", func() {
 			ExpectStatus: http.StatusNotFound,
 		})
 	})
-	ginkgo.It("create consumer", func() {
+	It("create consumer", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPut,
@@ -528,7 +526,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Key_Auth", func() {
 			ExpectStatus: http.StatusOK,
 		})
 	})
-	ginkgo.It("online debug with key-auth", func() {
+	It("online debug with key-auth", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPost,
@@ -545,7 +543,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Key_Auth", func() {
 			ExpectBody:   `{"code":0,"message":"","data":{"code":200,"header":{"Connection":["keep-alive"],"Content-Type":["application/octet-stream"],`,
 		})
 	})
-	ginkgo.It("online debug without key-auth", func() {
+	It("online debug without key-auth", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPost,
@@ -562,7 +560,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Key_Auth", func() {
 			ExpectBody:   `{"code":0,"message":"","data":{"code":401,"header":{"Connection":["keep-alive"],"Content-Type":["text/plain; charset=utf-8"]`,
 		})
 	})
-	ginkgo.It("delete the route just created", func() {
+	It("delete the route just created", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -571,7 +569,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Key_Auth", func() {
 			ExpectStatus: http.StatusOK,
 		})
 	})
-	ginkgo.It("hit the route just deleted", func() {
+	It("hit the route just deleted", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -581,7 +579,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Key_Auth", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("delete consumer", func() {
+	It("delete consumer", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -592,8 +590,8 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Key_Auth", func() {
 	})
 })
 
-var _ = ginkgo.Describe("Route_Online_Debug_Route_With_JWT_Auth", func() {
-	ginkgo.It("hit route that not exist", func() {
+var _ = Describe("Route_Online_Debug_Route_With_JWT_Auth", func() {
+	It("hit route that not exist", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -602,7 +600,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_JWT_Auth", func() {
 			ExpectBody:   "{\"error_msg\":\"404 Route Not Found\"}\n",
 		})
 	})
-	ginkgo.It("create route enable jwt-auth plugin", func() {
+	It("create route enable jwt-auth plugin", func() {
 		var routeBody map[string]interface{} = map[string]interface{}{
 			"name": "route1",
 			"uri":  "/hello",
@@ -613,7 +611,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_JWT_Auth", func() {
 			"upstream": upstream,
 		}
 		_reqRouteBody, err := json.Marshal(routeBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodPut,
@@ -624,7 +622,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_JWT_Auth", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("make sure the consumer is not created", func() {
+	It("make sure the consumer is not created", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodGet,
@@ -633,7 +631,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_JWT_Auth", func() {
 			ExpectStatus: http.StatusNotFound,
 		})
 	})
-	ginkgo.It("create consumer", func() {
+	It("create consumer", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPut,
@@ -653,16 +651,16 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_JWT_Auth", func() {
 			ExpectStatus: http.StatusOK,
 		})
 	})
-	ginkgo.It("online debug with JWT-auth", func() {
+	It("online debug with JWT-auth", func() {
 		jsonStr := `{"test":["test1"]}`
 		var _headerParams map[string]interface{}
 		err := json.Unmarshal([]byte(jsonStr), &_headerParams)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		jwtToken := base.GetJwtToken("user-key")
 		l := []string{jwtToken}
 		_headerParams["Authorization"] = l
 		headerParams, err := json.Marshal(_headerParams)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPost,
@@ -679,7 +677,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_JWT_Auth", func() {
 			ExpectBody:   `{"code":0,"message":"","data":{"code":200,"header":{"Connection":["keep-alive"],"Content-Type":["application/octet-stream"],`,
 		})
 	})
-	ginkgo.It("online debug without JWT-auth", func() {
+	It("online debug without JWT-auth", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPost,
@@ -696,7 +694,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_JWT_Auth", func() {
 			ExpectBody:   `{"code":0,"message":"","data":{"code":401,"header":{"Connection":["keep-alive"],"Content-Type":["text/plain; charset=utf-8"],`,
 		})
 	})
-	ginkgo.It("delete the route just created", func() {
+	It("delete the route just created", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -705,7 +703,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_JWT_Auth", func() {
 			ExpectStatus: http.StatusOK,
 		})
 	})
-	ginkgo.It("hit the route just deleted", func() {
+	It("hit the route just deleted", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -715,7 +713,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_JWT_Auth", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("delete consumer", func() {
+	It("delete consumer", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -726,8 +724,8 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_JWT_Auth", func() {
 	})
 })
 
-var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Files", func() {
-	ginkgo.It("hit route that not exist", func() {
+var _ = Describe("Route_Online_Debug_Route_With_Files", func() {
+	It("hit route that not exist", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -736,7 +734,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Files", func() {
 			ExpectBody:   "{\"error_msg\":\"404 Route Not Found\"}\n",
 		})
 	})
-	ginkgo.It("create route enable basic-auth plugin", func() {
+	It("create route enable basic-auth plugin", func() {
 		var routeBody map[string]interface{} = map[string]interface{}{
 			"name":     "route1",
 			"uri":      "/hello_",
@@ -744,7 +742,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Files", func() {
 			"upstream": upstream,
 		}
 		_reqRouteBody, err := json.Marshal(routeBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodPut,
@@ -755,9 +753,9 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Files", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("online debug with file", func() {
+	It("online debug with file", func() {
 		path, err := filepath.Abs("../../testdata/import/default.yaml")
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		files := []base.UploadFile{
 			{Name: "file", Filepath: path},
 		}
@@ -767,17 +765,17 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Files", func() {
 		jsonStr := `{"test":["test1"]}`
 		var _headerParams map[string]interface{}
 		err = json.Unmarshal([]byte(jsonStr), &_headerParams)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		l := []string{base.GetToken()}
 		_headerParams["Authorization"] = l
 		headerParams, err := json.Marshal(_headerParams)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 
 		basePath := base.ManagerAPIHost + "/apisix/admin/debug-request-forwarding"
 		requestBody, requestContentType, err := base.GetReader(headers, "multipart/form-data", files)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		httpRequest, err := http.NewRequest(http.MethodPost, basePath, requestBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		httpRequest.Header.Add("Content-Type", requestContentType)
 		httpRequest.Header.Add("Authorization", base.GetToken())
 		httpRequest.Header.Add("online_debug_request_protocol", "http")
@@ -786,23 +784,23 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Files", func() {
 		httpRequest.Header.Add("online_debug_header_params", string(headerParams))
 		client := &http.Client{}
 		resp, err := client.Do(httpRequest)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 
 		defer resp.Body.Close()
 
 		respBody, err := ioutil.ReadAll(resp.Body)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		realBody := gjson.Get(string(respBody), "data")
 		// todo get successful result and compare
-		gomega.Expect(realBody.String()).Should(gomega.ContainSubstring(`"data":{"paths":1,"routes":1}`))
+		Expect(realBody.String()).Should(ContainSubstring(`"data":{"paths":1,"routes":1}`))
 	})
 
-	ginkgo.It("verify the route just imported and delete data", func() {
+	It("verify the route just imported and delete data", func() {
 		time.Sleep(time.Duration(500) * time.Millisecond)
 		request, _ := http.NewRequest("GET", base.ManagerAPIHost+"/apisix/admin/routes", nil)
 		request.Header.Add("Authorization", base.GetToken())
 		resp, err := http.DefaultClient.Do(request)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		defer resp.Body.Close()
 		respBody, _ := ioutil.ReadAll(resp.Body)
 		list := gjson.Get(string(respBody), "data.rows").Value().([]interface{})
@@ -854,7 +852,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Files", func() {
 
 	})
 
-	ginkgo.It("hit the route just deleted", func() {
+	It("hit the route just deleted", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -865,7 +863,7 @@ var _ = ginkgo.Describe("Route_Online_Debug_Route_With_Files", func() {
 		})
 	})
 
-	ginkgo.It("hit the route just deleted", func() {
+	It("hit the route just deleted", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
