@@ -14,22 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package service
+package service_test
 
 import (
 	"encoding/json"
 	"net/http"
 	"time"
 
-	"github.com/onsi/ginkgo"
-	"github.com/onsi/gomega"
-
-	"github.com/onsi/ginkgo/extensions/table"
+	. "github.com/onsi/ginkgo/v2"
+	. "github.com/onsi/gomega"
 
 	"github.com/apisix/manager-api/test/e2e/base"
 )
 
-var _ = ginkgo.Describe("create service without plugin", func() {
+var _ = Describe("create service without plugin", func() {
 	var createServiceBody map[string]interface{} = map[string]interface{}{
 		"name": "testservice",
 		"upstream": map[string]interface{}{
@@ -53,9 +51,9 @@ var _ = ginkgo.Describe("create service without plugin", func() {
 			},
 		},
 	}
-	ginkgo.It("create service without plugin", func() {
+	It("create service without plugin", func() {
 		_createServiceBody, err := json.Marshal(createServiceBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodPut,
@@ -66,10 +64,10 @@ var _ = ginkgo.Describe("create service without plugin", func() {
 			ExpectBody:   []string{"\"id\":\"s1\"", "\"name\":\"testservice\""},
 		})
 	})
-	ginkgo.It("create service2 success", func() {
+	It("create service2 success", func() {
 		createServiceBody["name"] = "testservice2"
 		_createServiceBody, err := json.Marshal(createServiceBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodPut,
@@ -80,10 +78,10 @@ var _ = ginkgo.Describe("create service without plugin", func() {
 			ExpectBody:   []string{"\"id\":\"s2\"", "\"name\":\"testservice2\""},
 		})
 	})
-	ginkgo.It("create service failed, name existed", func() {
+	It("create service failed, name existed", func() {
 		createServiceBody["name"] = "testservice2"
 		_createServiceBody, err := json.Marshal(createServiceBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodPost,
@@ -95,10 +93,10 @@ var _ = ginkgo.Describe("create service without plugin", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("update service failed, name existed", func() {
+	It("update service failed, name existed", func() {
 		createServiceBody["name"] = "testservice2"
 		_createServiceBody, err := json.Marshal(createServiceBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodPut,
@@ -109,7 +107,7 @@ var _ = ginkgo.Describe("create service without plugin", func() {
 			ExpectBody:   `service name exists`,
 		})
 	})
-	ginkgo.It("get the service s1", func() {
+	It("get the service s1", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:     base.ManagerApiExpect(),
 			Method:     http.MethodGet,
@@ -120,7 +118,7 @@ var _ = ginkgo.Describe("create service without plugin", func() {
 			Sleep:      base.SleepTime,
 		})
 	})
-	ginkgo.It("create route using the service just created", func() {
+	It("create route using the service just created", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPut,
@@ -135,14 +133,14 @@ var _ = ginkgo.Describe("create service without plugin", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("batch test /server_port api", func() {
+	It("batch test /server_port api", func() {
 		time.Sleep(time.Duration(500) * time.Millisecond)
 		res := base.BatchTestServerPort(18, nil, "")
-		gomega.Expect(res["1980"]).Should(gomega.Equal(3))
-		gomega.Expect(res["1981"]).Should(gomega.Equal(6))
-		gomega.Expect(res["1982"]).Should(gomega.Equal(9))
+		Expect(res["1980"]).Should(Equal(3))
+		Expect(res["1981"]).Should(Equal(6))
+		Expect(res["1982"]).Should(Equal(9))
 	})
-	ginkgo.It("delete route", func() {
+	It("delete route", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -151,7 +149,7 @@ var _ = ginkgo.Describe("create service without plugin", func() {
 			ExpectStatus: http.StatusOK,
 		})
 	})
-	ginkgo.It("delete service", func() {
+	It("delete service", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -161,7 +159,7 @@ var _ = ginkgo.Describe("create service without plugin", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("delete service2", func() {
+	It("delete service2", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -171,7 +169,7 @@ var _ = ginkgo.Describe("create service without plugin", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("hit the route just deleted", func() {
+	It("hit the route just deleted", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -183,8 +181,8 @@ var _ = ginkgo.Describe("create service without plugin", func() {
 	})
 })
 
-var _ = ginkgo.Describe("create service with plugin", func() {
-	ginkgo.It("create service without plugin", func() {
+var _ = Describe("create service with plugin", func() {
+	It("create service without plugin", func() {
 		var createServiceBody map[string]interface{} = map[string]interface{}{
 			"name": "testservice",
 			"plugins": map[string]interface{}{
@@ -208,7 +206,7 @@ var _ = ginkgo.Describe("create service with plugin", func() {
 			},
 		}
 		_createServiceBody, err := json.Marshal(createServiceBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodPut,
@@ -219,7 +217,7 @@ var _ = ginkgo.Describe("create service with plugin", func() {
 			ExpectBody:   []string{"\"id\":\"s1\"", "\"name\":\"testservice\""},
 		})
 	})
-	ginkgo.It("get the service s1", func() {
+	It("get the service s1", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:     base.ManagerApiExpect(),
 			Method:     http.MethodGet,
@@ -230,7 +228,7 @@ var _ = ginkgo.Describe("create service with plugin", func() {
 			Sleep:      base.SleepTime,
 		})
 	})
-	ginkgo.It("create route using the service just created", func() {
+	It("create route using the service just created", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPut,
@@ -245,20 +243,20 @@ var _ = ginkgo.Describe("create service with plugin", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It(" hit routes and check the response header", func() {
+	It(" hit routes and check the response header", func() {
 		time.Sleep(time.Duration(500) * time.Millisecond)
 		basepath := base.APISIXHost
 		request, err := http.NewRequest("GET", basepath+"/server_port", nil)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		request.Header.Add("Authorization", base.GetToken())
 		resp, err := http.DefaultClient.Do(request)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		defer resp.Body.Close()
-		gomega.Expect(resp.StatusCode).Should(gomega.Equal(200))
-		gomega.Expect(resp.Header["X-Ratelimit-Limit"][0]).Should(gomega.Equal("100"))
-		gomega.Expect(resp.Header["X-Ratelimit-Remaining"][0]).Should(gomega.Equal("99"))
+		Expect(resp.StatusCode).Should(Equal(200))
+		Expect(resp.Header["X-Ratelimit-Limit"][0]).Should(Equal("100"))
+		Expect(resp.Header["X-Ratelimit-Remaining"][0]).Should(Equal("99"))
 	})
-	ginkgo.It("delete route", func() {
+	It("delete route", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -267,7 +265,7 @@ var _ = ginkgo.Describe("create service with plugin", func() {
 			ExpectStatus: http.StatusOK,
 		})
 	})
-	ginkgo.It("delete service", func() {
+	It("delete service", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -277,7 +275,7 @@ var _ = ginkgo.Describe("create service with plugin", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("hit the route just deleted", func() {
+	It("hit the route just deleted", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -289,8 +287,8 @@ var _ = ginkgo.Describe("create service with plugin", func() {
 	})
 })
 
-var _ = ginkgo.Describe("create service with all options via POST method", func() {
-	ginkgo.It("create service with all options via POST method", func() {
+var _ = Describe("create service with all options via POST method", func() {
+	It("create service with all options via POST method", func() {
 		var createServiceBody map[string]interface{} = map[string]interface{}{
 			"id":   "s2",
 			"name": "testservice22",
@@ -324,7 +322,7 @@ var _ = ginkgo.Describe("create service with all options via POST method", func(
 			},
 		}
 		_createServiceBody, err := json.Marshal(createServiceBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Desc:         "create service with all options via POST method",
 			Object:       base.ManagerApiExpect(),
@@ -336,7 +334,7 @@ var _ = ginkgo.Describe("create service with all options via POST method", func(
 			ExpectBody:   "\"id\":\"s2\"",
 		})
 	})
-	ginkgo.It("get the service s2", func() {
+	It("get the service s2", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:     base.ManagerApiExpect(),
 			Method:     http.MethodGet,
@@ -347,7 +345,7 @@ var _ = ginkgo.Describe("create service with all options via POST method", func(
 			Sleep:      base.SleepTime,
 		})
 	})
-	ginkgo.It("create route using the service just created", func() {
+	It("create route using the service just created", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPut,
@@ -362,7 +360,7 @@ var _ = ginkgo.Describe("create service with all options via POST method", func(
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("verify route", func() {
+	It("verify route", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -372,7 +370,7 @@ var _ = ginkgo.Describe("create service with all options via POST method", func(
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("delete route", func() {
+	It("delete route", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -381,7 +379,7 @@ var _ = ginkgo.Describe("create service with all options via POST method", func(
 			ExpectStatus: http.StatusOK,
 		})
 	})
-	ginkgo.It("delete service", func() {
+	It("delete service", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -391,7 +389,7 @@ var _ = ginkgo.Describe("create service with all options via POST method", func(
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("hit the route just deleted", func() {
+	It("hit the route just deleted", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
@@ -403,8 +401,8 @@ var _ = ginkgo.Describe("create service with all options via POST method", func(
 	})
 })
 
-var _ = ginkgo.Describe("service update use patch method", func() {
-	ginkgo.It("create service without plugin", func() {
+var _ = Describe("service update use patch method", func() {
+	It("create service without plugin", func() {
 		var createServiceBody map[string]interface{} = map[string]interface{}{
 			"name": "testservice",
 			"upstream": map[string]interface{}{
@@ -419,7 +417,7 @@ var _ = ginkgo.Describe("service update use patch method", func() {
 			},
 		}
 		_createServiceBody, err := json.Marshal(createServiceBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Desc:         "create service without plugin",
 			Object:       base.ManagerApiExpect(),
@@ -431,7 +429,7 @@ var _ = ginkgo.Describe("service update use patch method", func() {
 			ExpectBody:   "\"name\":\"testservice\",\"upstream\":{\"nodes\":[{\"host\":\"" + base.UpstreamIp + "\",\"port\":1980,\"weight\":1}],\"type\":\"roundrobin\"}}",
 		})
 	})
-	ginkgo.It("update service use patch method", func() {
+	It("update service use patch method", func() {
 		var createServiceBody map[string]interface{} = map[string]interface{}{
 			"name": "testpatch",
 			"upstream": map[string]interface{}{
@@ -446,7 +444,7 @@ var _ = ginkgo.Describe("service update use patch method", func() {
 			},
 		}
 		_createServiceBody, err := json.Marshal(createServiceBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodPatch,
@@ -457,7 +455,7 @@ var _ = ginkgo.Describe("service update use patch method", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("get the service s5", func() {
+	It("get the service s5", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:     base.ManagerApiExpect(),
 			Method:     http.MethodGet,
@@ -468,7 +466,7 @@ var _ = ginkgo.Describe("service update use patch method", func() {
 			Sleep:      base.SleepTime,
 		})
 	})
-	ginkgo.It("Update service using path parameter patch method", func() {
+	It("Update service using path parameter patch method", func() {
 		var createUpstreamBody map[string]interface{} = map[string]interface{}{
 			"type": "roundrobin",
 			"nodes": []map[string]interface{}{
@@ -480,7 +478,7 @@ var _ = ginkgo.Describe("service update use patch method", func() {
 			},
 		}
 		_createUpstreamBody, err := json.Marshal(createUpstreamBody)
-		gomega.Expect(err).To(gomega.BeNil())
+		Expect(err).To(BeNil())
 		base.RunTestCase(base.HttpTestCase{
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPatch,
@@ -493,7 +491,7 @@ var _ = ginkgo.Describe("service update use patch method", func() {
 			ExpectStatus: http.StatusOK,
 		})
 	})
-	ginkgo.It("get service data", func() {
+	It("get service data", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodGet,
@@ -504,7 +502,7 @@ var _ = ginkgo.Describe("service update use patch method", func() {
 			Sleep:        base.SleepTime,
 		})
 	})
-	ginkgo.It("delete service", func() {
+	It("delete service", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -515,7 +513,7 @@ var _ = ginkgo.Describe("service update use patch method", func() {
 	})
 })
 
-var _ = ginkgo.Describe("test service delete", func() {
+var _ = Describe("test service delete", func() {
 	var createServiceBody map[string]interface{} = map[string]interface{}{
 		"name": "testservice",
 		"upstream": map[string]interface{}{
@@ -530,13 +528,13 @@ var _ = ginkgo.Describe("test service delete", func() {
 		},
 	}
 	_createServiceBody, err := json.Marshal(createServiceBody)
-	gomega.Expect(err).To(gomega.BeNil())
+	Expect(err).To(BeNil())
 
-	table.DescribeTable("test service delete",
+	DescribeTable("test service delete",
 		func(tc base.HttpTestCase) {
 			base.RunTestCase(tc)
 		},
-		table.Entry("create service without plugin", base.HttpTestCase{
+		Entry("create service without plugin", base.HttpTestCase{
 			Desc:         "create service without plugin",
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodPut,
@@ -546,7 +544,7 @@ var _ = ginkgo.Describe("test service delete", func() {
 			ExpectStatus: http.StatusOK,
 			ExpectBody:   "\"name\":\"testservice\",\"upstream\":{\"nodes\":[{\"host\":\"" + base.UpstreamIp + "\",\"port\":1980,\"weight\":1}],\"type\":\"roundrobin\"}}",
 		}),
-		table.Entry("create route use service s1", base.HttpTestCase{
+		Entry("create route use service s1", base.HttpTestCase{
 			Desc:   "create route use service s1",
 			Object: base.ManagerApiExpect(),
 			Method: http.MethodPut,
@@ -567,7 +565,7 @@ var _ = ginkgo.Describe("test service delete", func() {
 			ExpectStatus: http.StatusOK,
 			ExpectBody:   "\"service_id\":\"s1\"",
 		}),
-		table.Entry("hit route on apisix", base.HttpTestCase{
+		Entry("hit route on apisix", base.HttpTestCase{
 			Object:       base.APISIXExpect(),
 			Method:       http.MethodGet,
 			Path:         "/hello",
@@ -575,7 +573,7 @@ var _ = ginkgo.Describe("test service delete", func() {
 			ExpectBody:   "hello world",
 			Sleep:        base.SleepTime,
 		}),
-		table.Entry("delete service failed", base.HttpTestCase{
+		Entry("delete service failed", base.HttpTestCase{
 			Desc:         "delete service failed",
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -584,7 +582,7 @@ var _ = ginkgo.Describe("test service delete", func() {
 			ExpectStatus: http.StatusBadRequest,
 			ExpectBody:   "route: route1 is using this service",
 		}),
-		table.Entry("delete route first", base.HttpTestCase{
+		Entry("delete route first", base.HttpTestCase{
 			Desc:         "delete route first",
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -592,7 +590,7 @@ var _ = ginkgo.Describe("test service delete", func() {
 			Headers:      map[string]string{"Authorization": base.GetToken()},
 			ExpectStatus: http.StatusOK,
 		}),
-		table.Entry("check route exist", base.HttpTestCase{
+		Entry("check route exist", base.HttpTestCase{
 			Desc:         "check route exist",
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -600,7 +598,7 @@ var _ = ginkgo.Describe("test service delete", func() {
 			Headers:      map[string]string{"Authorization": base.GetToken()},
 			ExpectStatus: http.StatusNotFound,
 		}),
-		table.Entry("delete service success", base.HttpTestCase{
+		Entry("delete service success", base.HttpTestCase{
 			Desc:         "delete service success",
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodDelete,
@@ -608,7 +606,7 @@ var _ = ginkgo.Describe("test service delete", func() {
 			Headers:      map[string]string{"Authorization": base.GetToken()},
 			ExpectStatus: http.StatusOK,
 		}),
-		table.Entry("check the service exist", base.HttpTestCase{
+		Entry("check the service exist", base.HttpTestCase{
 			Desc:         "check the exist",
 			Object:       base.ManagerApiExpect(),
 			Method:       http.MethodGet,
@@ -618,7 +616,7 @@ var _ = ginkgo.Describe("test service delete", func() {
 		}))
 })
 
-var _ = ginkgo.Describe("test service with hosts", func() {
+var _ = Describe("test service with hosts", func() {
 	var createServiceBody = map[string]interface{}{
 		"name": "testservice",
 		"upstream": map[string]interface{}{
@@ -637,7 +635,7 @@ var _ = ginkgo.Describe("test service with hosts", func() {
 		},
 	}
 	_createServiceBody, err := json.Marshal(createServiceBody)
-	gomega.Expect(err).To(gomega.BeNil())
+	Expect(err).To(BeNil())
 
 	var createRouteBody = map[string]interface{}{
 		"id":   "r1",
@@ -652,13 +650,13 @@ var _ = ginkgo.Describe("test service with hosts", func() {
 		"service_id": "s1",
 	}
 	_createRouteBody, err := json.Marshal(createRouteBody)
-	gomega.Expect(err).To(gomega.BeNil())
+	Expect(err).To(BeNil())
 
-	table.DescribeTable("test service with hosts",
+	DescribeTable("test service with hosts",
 		func(tc func() base.HttpTestCase) {
 			base.RunTestCase(tc())
 		},
-		table.Entry("create service with hosts params", func() base.HttpTestCase {
+		Entry("create service with hosts params", func() base.HttpTestCase {
 			return base.HttpTestCase{
 				Desc:         "create service with hosts params",
 				Object:       base.ManagerApiExpect(),
@@ -669,7 +667,7 @@ var _ = ginkgo.Describe("test service with hosts", func() {
 				ExpectStatus: http.StatusOK,
 			}
 		}),
-		table.Entry("create route use service s1", func() base.HttpTestCase {
+		Entry("create route use service s1", func() base.HttpTestCase {
 			return base.HttpTestCase{
 				Desc:         "create route use service s1",
 				Object:       base.ManagerApiExpect(),
@@ -680,7 +678,7 @@ var _ = ginkgo.Describe("test service with hosts", func() {
 				ExpectStatus: http.StatusOK,
 			}
 		}),
-		table.Entry("hit route by test.com", func() base.HttpTestCase {
+		Entry("hit route by test.com", func() base.HttpTestCase {
 			return base.HttpTestCase{
 				Object: base.APISIXExpect(),
 				Method: http.MethodGet,
@@ -693,7 +691,7 @@ var _ = ginkgo.Describe("test service with hosts", func() {
 				Sleep:        base.SleepTime,
 			}
 		}),
-		table.Entry("hit route by test1.com", func() base.HttpTestCase {
+		Entry("hit route by test1.com", func() base.HttpTestCase {
 			return base.HttpTestCase{
 				Object: base.APISIXExpect(),
 				Method: http.MethodGet,
@@ -706,7 +704,7 @@ var _ = ginkgo.Describe("test service with hosts", func() {
 				Sleep:        base.SleepTime,
 			}
 		}),
-		table.Entry("hit route by test2.com", func() base.HttpTestCase {
+		Entry("hit route by test2.com", func() base.HttpTestCase {
 			return base.HttpTestCase{
 				Object: base.APISIXExpect(),
 				Method: http.MethodGet,
@@ -718,7 +716,7 @@ var _ = ginkgo.Describe("test service with hosts", func() {
 				Sleep:        base.SleepTime,
 			}
 		}),
-		table.Entry("delete route", func() base.HttpTestCase {
+		Entry("delete route", func() base.HttpTestCase {
 			return base.HttpTestCase{
 				Desc:         "delete route first",
 				Object:       base.ManagerApiExpect(),
@@ -728,7 +726,7 @@ var _ = ginkgo.Describe("test service with hosts", func() {
 				ExpectStatus: http.StatusOK,
 			}
 		}),
-		table.Entry("delete service", func() base.HttpTestCase {
+		Entry("delete service", func() base.HttpTestCase {
 			return base.HttpTestCase{
 				Desc:         "delete service success",
 				Object:       base.ManagerApiExpect(),
