@@ -20,20 +20,19 @@ import (
 	"testing"
 	"time"
 
-	"github.com/onsi/ginkgo"
-	"github.com/onsi/gomega"
+	. "github.com/onsi/ginkgo/v2"
+	. "github.com/onsi/gomega"
 
 	"github.com/apisix/manager-api/test/e2e/base"
 )
 
 func TestStreamRoute(t *testing.T) {
-	gomega.RegisterFailHandler(ginkgo.Fail)
-	ginkgo.RunSpecs(t, "stream route suite")
+	RegisterFailHandler(Fail)
+	RunSpecs(t, "Stream Route Suite")
 }
 
-var _ = ginkgo.AfterSuite(func() {
-	base.CleanResource("stream_routes")
-	base.CleanResource("upstreams")
-	base.CleanResource("ssl")
+var _ = BeforeSuite(func() {
+	base.CleanAllResource()
+	base.RestartManagerAPI()
 	time.Sleep(base.SleepTime)
 })
