@@ -14,14 +14,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package version
+package version_test
 
 import (
 	"testing"
+	"time"
 
-	"github.com/onsi/ginkgo"
+	"github.com/apisix/manager-api/test/e2e/base"
+	. "github.com/onsi/ginkgo/v2"
+	. "github.com/onsi/gomega"
 )
 
-func TestRoute(t *testing.T) {
-	ginkgo.RunSpecs(t, "version suite")
+func TestVersion(t *testing.T) {
+	RegisterFailHandler(Fail)
+	RunSpecs(t, "Version Suite")
 }
+
+var _ = BeforeSuite(func() {
+	base.CleanAllResource()
+	time.Sleep(base.SleepTime)
+})
